@@ -33,7 +33,7 @@ def raises_unsupported_algorithm(reason):
     with pytest.raises(UnsupportedAlgorithm) as exc_info:
         yield exc_info
 
-    assert exc_info.value._reason is reason
+    assert exc_info.value._reason == reason
 
 
 T = typing.TypeVar("T")
@@ -243,9 +243,6 @@ def load_pkcs1_vectors(vector_data):
             attr = None
 
         if private_key_vector is None or public_key_vector is None:
-            # Random garbage to defeat CPython's peephole optimizer so that
-            # coverage records correctly: https://bugs.python.org/issue2506
-            1 + 1
             continue
 
         if line.startswith("# Private key"):
@@ -921,8 +918,8 @@ class WycheproofTest:
         return cache_val
 
 
-def load_wycheproof_tests(wycheproof, test_file):
-    path = os.path.join(wycheproof, "testvectors", test_file)
+def load_wycheproof_tests(wycheproof, test_file, subdir):
+    path = os.path.join(wycheproof, subdir, test_file)
     with open(path) as f:
         data = json.load(f)
         for group in data.pop("testGroups"):
