@@ -102,6 +102,18 @@ class TestOCSPRequest:
             b"{\x80Z\x1d7&\xb8\xb8OH\xd2\xf8\xbf\xd7-\xfd"
         )
 
+    def test_load_request_with_acceptable_responses(self):
+        req = _load_data(
+            os.path.join("x509", "ocsp", "req-acceptable-responses.der"),
+            ocsp.load_der_ocsp_request,
+        )
+        assert len(req.extensions) == 1
+        ext = req.extensions[0]
+        assert ext.critical is False
+        assert ext.value == x509.OCSPAcceptableResponses(
+            [x509.ObjectIdentifier("1.3.6.1.5.5.7.48.1.1")]
+        )
+
     def test_load_request_with_unknown_extension(self):
         req = _load_data(
             os.path.join("x509", "ocsp", "req-ext-unknown-oid.der"),
@@ -191,7 +203,10 @@ class TestOCSPRequestBuilder:
         builder = ocsp.OCSPRequestBuilder()
         with pytest.raises(ValueError):
             builder.add_certificate_by_hash(
-                b"0" * 20, b"0" * 20, 1, "notahash"  # type:ignore[arg-type]
+                b"0" * 20,
+                b"0" * 20,
+                1,
+                "notahash",  # type:ignore[arg-type]
             )
         with pytest.raises(ValueError):
             builder.add_certificate_by_hash(
@@ -292,7 +307,7 @@ class TestOCSPRequestBuilder:
         assert req.extensions[0].critical is critical
 
     def test_add_cert_by_hash(self):
-        cert, issuer = _cert_and_issuer()
+        cert, _ = _cert_and_issuer()
         builder = ocsp.OCSPRequestBuilder()
         h = hashes.Hash(hashes.SHA1())
         h.update(cert.issuer.public_bytes())
@@ -343,7 +358,9 @@ class TestOCSPResponseBuilder:
 
     def test_invalid_add_response(self):
         cert, issuer = _cert_and_issuer()
-        time = datetime.datetime.utcnow()
+        time = datetime.datetime.now(datetime.timezone.utc).replace(
+            tzinfo=None
+        )
         reason = x509.ReasonFlags.cessation_of_operation
         builder = ocsp.OCSPResponseBuilder()
         with pytest.raises(TypeError):
@@ -502,13 +519,18 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         with pytest.raises(TypeError):
             builder.add_extension(
-                "notanextension", True  # type: ignore[arg-type]
+                "notanextension",  # type: ignore[arg-type]
+                True,
             )
 
     def test_unsupported_extension(self):
         root_cert, private_key = _generate_root()
         cert, issuer = _cert_and_issuer()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
 
@@ -543,7 +565,9 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         _, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now().replace(tzinfo=None).replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.add_response(
@@ -563,7 +587,9 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now().replace(tzinfo=None).replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -585,7 +611,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -621,7 +651,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         revoked_date = this_update - datetime.timedelta(days=300)
@@ -651,7 +685,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -678,7 +716,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = (
@@ -702,7 +744,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         revoked_date = this_update - datetime.timedelta(days=300)
         builder = builder.responder_id(
@@ -731,7 +777,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         revoked_date = this_update - datetime.timedelta(days=300)
@@ -761,7 +811,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -788,8 +842,12 @@ class TestOCSPResponseBuilder:
     def test_invalid_sign_responder_cert_does_not_match_private_key(self):
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
-        root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        root_cert, _ = _generate_root()
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -814,7 +872,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = (
@@ -870,7 +932,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, _ = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -898,7 +964,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -921,7 +991,11 @@ class TestOCSPResponseBuilder:
         builder = ocsp.OCSPResponseBuilder()
         cert, issuer = _cert_and_issuer()
         root_cert, private_key = _generate_root()
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         builder = builder.responder_id(
@@ -1368,7 +1442,11 @@ class TestOCSPEdDSA:
         cert, issuer = _cert_and_issuer()
         private_key = ed25519.Ed25519PrivateKey.generate()
         root_cert, _ = _generate_root(private_key, None)
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         revoked_date = this_update - datetime.timedelta(days=300)
@@ -1396,7 +1474,11 @@ class TestOCSPEdDSA:
         cert, issuer = _cert_and_issuer()
         private_key = ed25519.Ed25519PrivateKey.generate()
         root_cert, _ = _generate_root(private_key, None)
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         revoked_date = this_update - datetime.timedelta(days=300)
@@ -1435,7 +1517,11 @@ class TestOCSPEdDSA:
         cert, issuer = _cert_and_issuer()
         private_key = ed448.Ed448PrivateKey.generate()
         root_cert, _ = _generate_root(private_key, None)
-        current_time = datetime.datetime.utcnow().replace(microsecond=0)
+        current_time = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(tzinfo=None)
+            .replace(microsecond=0)
+        )
         this_update = current_time - datetime.timedelta(days=1)
         next_update = this_update + datetime.timedelta(days=7)
         revoked_date = this_update - datetime.timedelta(days=300)
